vm_outcome_with_args

Function vm_outcome_with_args 

pub fn vm_outcome_with_args(
    source: &str,
    program_args: &[String],
    tier: Option<&dyn NativeTier>,
) -> RunOutcome
vm_outcome with the program argument vector and an optional private native tier (so a differential test can observe THAT program’s JIT compile counters in isolation — the process-wide tier’s counters are shared by every test in the binary).